@@ -42,12 +42,6 @@
 
 #define PLUGIN_WEBSITE  "https://docs.xfce.org/panel-plugins/xfce4-indicator-plugin"
 
-#ifdef LIBXFCE4UI_CHECK_VERSION
-#if LIBXFCE4UI_CHECK_VERSION (4,9,0)
-#define HAS_ONLINE_HELP
-#endif
-#endif
-
 
 /* known indicator names */
 static const gchar *pretty_names[][3] =
@@ -550,25 +544,16 @@ static void
 indicator_dialog_help_button_clicked (IndicatorDialog *dialog,
                                       GtkWidget       *button)
 {
-  //#ifndef HAS_ONLINE_HELP
   gboolean result;
-  //#endif
 
   g_return_if_fail (XFCE_IS_INDICATOR_DIALOG (dialog));
   g_return_if_fail (GTK_IS_BUTTON (button));
   g_return_if_fail (GTK_IS_WINDOW (dialog->dialog));
 
-  /* Doesn't seem to work */
-  //#ifdef HAS_ONLINE_HELP
-  //xfce_dialog_show_help (GTK_WINDOW (dialog->dialog), "xfce4-indicator", "dialog", NULL);
-  //#else
-
   result = g_spawn_command_line_async ("exo-open --launch WebBrowser " PLUGIN_WEBSITE, NULL);
 
   if (G_UNLIKELY (result == FALSE))
     g_warning (_("Unable to open the following url: %s"), PLUGIN_WEBSITE);
-
-  //#endif
 }
 
 
